@@ -210,15 +210,15 @@ class QottoAuthTestApi(QottoAuthApi):
         else:
             return dict(deleted=False)
 
-    def identity(self, identityId):
+    def identity(self, id):
         return dict(
-            id=self._identities[identityId].identity_id,
-            user=self.user(self._identities[identityId].user.user_id) if self._identities[identityId].user else None,
-            providerId=self._identities[identityId].provider_id,
-            name=self._identities[identityId].name,
-            email=self._identities[identityId].email,
-            blocked=self._identities[identityId].blocked,
-        ) if identityId in self._identities else None
+            id=self._identities[id].identity_id,
+            user=self.user(self._identities[id].user.user_id) if self._identities[id].user else None,
+            providerId=self._identities[id].provider_id,
+            name=self._identities[id].name,
+            email=self._identities[id].email,
+            blocked=self._identities[id].blocked,
+        ) if id in self._identities else None
 
     def identities(self):
         return [self.identity(id) for id in self._identities]
@@ -235,17 +235,17 @@ class QottoAuthTestApi(QottoAuthApi):
         else:
             return dict(deleted=False)
 
-    def authorization(self, authorizationId):
+    def authorization(self, id):
         return dict(
-            id=self._authorizations[authorizationId].authorization_id,
-            name=self._authorizations[authorizationId].name,
-            description=self._authorizations[authorizationId].description,
-            organization=self.organization(self._authorizations[authorizationId].organization.organization_id),
-            inheritance=self._authorizations[authorizationId].inheritance,
-            matching=str(self._authorizations[authorizationId].matching),
+            id=self._authorizations[id].authorization_id,
+            name=self._authorizations[id].name,
+            description=self._authorizations[id].description,
+            organization=self.organization(self._authorizations[id].organization.organization_id),
+            inheritance=self._authorizations[id].inheritance,
+            matching=str(self._authorizations[id].matching),
             permissions=[self.permission(permission.permission_id) for permission in
-                         self._authorization_permissions[authorizationId]],
-        ) if authorizationId in self._authorizations else None
+                         self._authorization_permissions[id]],
+        ) if id in self._authorizations else None
 
     def authorizations(self):
         return [self.authorization(id) for id in self._authorizations]
@@ -273,16 +273,16 @@ class QottoAuthTestApi(QottoAuthApi):
         else:
             return dict(deleted=False)
 
-    def role(self, roleId):
+    def role(self, id):
         return dict(
-            id=self._roles[roleId].role_id,
-            name=self._roles[roleId].name,
-            description=self._roles[roleId].description,
-            organization=self.organization(self._roles[roleId].organization.organization_id),
-            inheritance=self._roles[roleId].inheritance,
+            id=self._roles[id].role_id,
+            name=self._roles[id].name,
+            description=self._roles[id].description,
+            organization=self.organization(self._roles[id].organization.organization_id),
+            inheritance=self._roles[id].inheritance,
             authorizations=[self.authorization(authorization.authorization_id) for authorization in
-                            self._role_authorizations[roleId]],
-        ) if roleId in self._roles else None
+                            self._role_authorizations[id]],
+        ) if id in self._roles else None
 
     def roles(self):
         return [self.role(id) for id in self._roles]
@@ -308,12 +308,12 @@ class QottoAuthTestApi(QottoAuthApi):
         else:
             return dict(deleted=False)
 
-    def organization(self, organizationId):
+    def organization(self, id):
         return dict(
-            id=self._organizations[organizationId].organization_id,
-            name=self._organizations[organizationId].name,
-            namespace=str(self._organizations[organizationId].namespace),
-        ) if organizationId in self._organizations else None
+            id=self._organizations[id].organization_id,
+            name=self._organizations[id].name,
+            namespace=str(self._organizations[id].namespace),
+        ) if id in self._organizations else None
 
     def organizations(self):
         return [self.organization(id) for id in self._organizations]
@@ -346,15 +346,15 @@ class QottoAuthTestApi(QottoAuthApi):
         else:
             return dict(deleted=False)
 
-    def member(self, memberId):
+    def member(self, id):
         return dict(
-            id=self._members[memberId].member_id,
-            user=self.user(self._members[memberId].user.user_id),
-            organization=self.organization(self._members[memberId].organization.organization_id),
-            roles=[self.role(role.role_id) for role in self._member_roles[memberId]],
+            id=self._members[id].member_id,
+            user=self.user(self._members[id].user.user_id),
+            organization=self.organization(self._members[id].organization.organization_id),
+            roles=[self.role(role.role_id) for role in self._member_roles[id]],
             authorizations=[self.authorization(authorization.authorization_id) for authorization in
-                            self._member_authorizations[memberId]],
-        ) if memberId in self._members else None
+                            self._member_authorizations[id]],
+        ) if id in self._members else None
 
     def memberFromCookies(self, tokenCookie, secretCookie):
         for member_id, (member_token, member_secret) in self._member_cookies.items():
