@@ -4,7 +4,7 @@ from __future__ import annotations
 
 from dataclasses import dataclass
 from enum import Enum
-from typing import Union
+from typing import Union, Optional
 
 __all__ = [
     'Namespace',
@@ -13,9 +13,12 @@ __all__ = [
     'Permission',
     'Organization',
     'Authorization',
+    'Role',
     'User',
     'Member',
     'Account',
+    'Cookie',
+    'Identity',
 ]
 
 
@@ -26,6 +29,9 @@ class Matching(Enum):
     DESCENDANT = 'DESCENDANT'
     SAME_BRANCH = 'SAME_BRANCH'
 
+    def __str__(self) -> str:
+        return self.name
+
 
 class Namespace:
     _nodes: list[str]
@@ -96,6 +102,9 @@ class Namespace:
                 and len(self) == len(other)
                 and self.path == other.path)
 
+    def __hash__(self):
+        return hash(self.path)
+
     def __le__(self, other) -> bool:
         return (isinstance(other, Namespace)
                 and len(self) >= len(other)
@@ -126,82 +135,72 @@ class Namespace:
         return self.path
 
 
-@dataclass
+@dataclass(frozen=True)
 class Application:
     application_id: str
     name: str
     description: str
 
-    def __str__(self) -> str:
-        return f'App#{self.application_id} {self.name}'
 
-
-@dataclass
+@dataclass(frozen=True)
 class Permission:
     application: Application
     permission_id: str
     name: str
     description: str
 
-    def __str__(self) -> str:
-        return f'Perm#{self.permission_id} {self.application.name}::{self.name}'
 
-
-@dataclass
+@dataclass(frozen=True)
 class Organization:
     organization_id: str
     name: str
     namespace: Namespace
 
-    def __str__(self) -> str:
-        return f'Org#{self.organization_id} {self.name}'
-
 
+@dataclass(frozen=True)
 class Authorization:
-
-    def __init__(
-            self,
-            authorization_id: str,
-            name: str,
-            description: str,
-            permissions: set[Permission],
-            organization: Organization,
-            inheritance: bool,
-            matching: Matching,
-    ):
-        self.authorization_id = authorization_id
-        self.name = name
-        self.description = description
-        self.permissions = permissions
-        self.organization = organization
-        self.inheritance = inheritance
-        self.matching = matching
-
-    def __str__(self):
-        return f'Auth#{self.authorization_id} {self.name}'
+    authorization_id: str
+    name: str
+    description: str
+    organization: Organization
+    inheritance: bool
+    matching: Matching
 
 
-@dataclass
+@dataclass(frozen=True)
+class Role:
+    role_id: str
+    name: str
+    description: str
+    organization: Organization
+    inheritance: bool
+
+
+@dataclass(frozen=True)
+class Identity:
+    identity_id: str
+    name: str
+    provider_id: str
+    email: str
+    user: Optional[User]
+    blocked: bool
+
+
+@dataclass(frozen=True)
 class User:
     user_id: str
     name: str
-    is_superuser: bool = False
-
-    def __str__(self):
-        return f'{"SuperUser" if self.is_superuser else "User"}#{self.user_id} {self.name}'
+    is_superuser: bool
 
 
-@dataclass
+@dataclass(frozen=True)
 class Member:
     member_id: str
     user: User
     organization: Organization
 
-    def __str__(self):
-        return f'Member#{self.member_id} {self.user} member in {self.organization}'
 
-
-@dataclass
+@dataclass(frozen=True)
 class Account:
     account_id: str
     application: Application
@@ -209,5 +208,15 @@ class Account:
     enabled: bool
     data: dict
 
+
+@dataclass(frozen=True)
+class Cookie:
+    name: str
+    value: str
+    domain: str
+    max_age: int
+    secure: bool
+    http_only: bool
+
     def __str__(self):
-        return f'{"DisabledAccount" if not self.enabled else "Account"}#{self.account_id} {self.user} account for {self.application}'
+        return f'Cookie"{self.name}={self.value}"'
